pub enum ScaleMode {
Stretch,
Repeat,
}Variants
Stretch
will strech audio if the elapsed time specified by interval is larger than the elapsed time of the audio
Repeat
will loop if the elapsed time specified by interval is larger than the elapsed time of the audio