EventKind

Enum EventKind 

pub enum EventKind {
    Quit,
    Resize {
        width: i32,
        height: i32,
    },
    MouseMove {
        x: f32,
        y: f32,
        dx: f32,
        dy: f32,
    },
    MouseDown {
        button_code: MouseCode,
        x: f32,
        y: f32,
    },
    MouseUp {
        button_code: MouseCode,
        x: f32,
        y: f32,
    },
    MouseWheel {
        button_code: MouseCode,
    },
    TouchMove {
        finger_id: i32,
        x: f32,
        y: f32,
        dx: f32,
        dy: f32,
    },
    TouchDown {
        finger_id: i32,
        x: f32,
        y: f32,
        dx: f32,
        dy: f32,
    },
    TouchUp {
        finger_id: i32,
        x: f32,
        y: f32,
        dx: f32,
        dy: f32,
    },
    KeyDown {
        code: KeyCode,
    },
    KeyUp {
        code: KeyCode,
    },
}

Variants



Quit

Description

This event fires only when the user clicks on the “x” button on desktop. This event doesn’t really apply in the browser environment, unless I do my own virtual window thingy, which im not going to do



Resize

Description

Whenever the window resizes this is called

Fields

width: i32
height: i32


MouseMove

Description

If the user moves the mouse, this event gets enqueued

Fields

dx: f32
dy: f32


MouseDown

Description

If the user pushes a mouse button, this event gets enqueued

Fields

button_code: MouseCode


MouseUp

Description

if the user releases a mouse button, this event gets enqueues

Members

  • x and y are absolute coordinates in standard screen space, so (0,0) is top-left corner and (width,height) is botton right corner of the window

Fields

button_code: MouseCode


MouseWheel

Description

This event will appear in the event queue when something happens with the mouse wheel

Fields

button_code: MouseCode


TouchMove

Description

This event should fire when a the underlying backend detects finger movement

Members

  • finger_id - a unique id given to each finger moving
  • x/y - the normalized absolute postions

Fields

finger_id: i32
dx: f32
dy: f32


TouchDown

Fields

finger_id: i32
dx: f32
dy: f32


TouchUp

Fields

finger_id: i32
dx: f32
dy: f32


KeyDown

Fields

code: KeyCode


KeyUp

Fields

code: KeyCode

Implementations

Source

impl EventKind

pub fn mouse_pos(&self) -> Vec2<f32>

pub fn disp(&self) -> Vec2<f32>

pub fn wheel(&self) -> f32

pub fn disp_mouse_only(&self) -> Vec2<f32>